"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorView = void 0;
const http_status_codes_1 = require("http-status-codes");
const errorCodes_1 = require("../errors/errorCodes");
class ErrorView {
    constructor(error) {
        this.error = this.getError(error);
        this.status = this.getStatus();
        this.reason = (0, http_status_codes_1.getReasonPhrase)(this.status);
        this.code = this.createErrorCode();
        this.stack = this.error.stack;
        this.body = this.createBody();
    }
    createErrorCode() {
        if ('code' in this.error)
            return String(this.error.code);
        return errorCodes_1.ErrorCode.KERNEL;
    }
    isError(value) {
        return value instanceof Error;
    }
    isString(value) {
        return typeof value === 'string';
    }
    isNumber(value) {
        return typeof value === 'number';
    }
    isAxiosError(e) {
        return 'isAxiosError' in e && e.isAxiosError === true;
    }
    normalizeError(e) {
        if (false === this.isAxiosError(e)) {
            return e;
        }
        let details = {
            baseUrl: e.config?.baseURL,
            url: e.config?.url,
            query: e.config?.params,
            responseCode: e.response?.status || e.code,
        };
        return Object.assign(new Error(e.message), { ...e.toJSON(), details });
    }
    getError(value) {
        if (this.isError(value)) {
            return this.normalizeError(value);
        }
        if (this.isString(value))
            return new Error(value);
        if (this.isNumber(value))
            return new Error((0, http_status_codes_1.getReasonPhrase)(value));
        return new Error(http_status_codes_1.ReasonPhrases.INTERNAL_SERVER_ERROR);
    }
    getStatus() {
        if ('status' in this.error)
            return Number(this.error.status);
        if ('statusCode' in this.error)
            return Number(this.error.statusCode);
        return http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR;
    }
    createBody() {
        let details = {};
        if ('details' in this.error) {
            details = this.error.details;
        }
        let body = {
            errorCode: this.code,
            statusCode: this.status,
            reason: (0, http_status_codes_1.getReasonPhrase)(this.status),
            message: this.error.message,
            details,
        };
        return body;
    }
    toJSON() {
        return this.body;
    }
}
exports.ErrorView = ErrorView;
//# sourceMappingURL=errorView.js.map